Unnamed repository; edit this file 'description' to name the repository.
Diffstat (limited to 'crates/hir-expand/src/mod_path.rs')
-rw-r--r--crates/hir-expand/src/mod_path.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/crates/hir-expand/src/mod_path.rs b/crates/hir-expand/src/mod_path.rs
index 51e449fe50..1712c28aa8 100644
--- a/crates/hir-expand/src/mod_path.rs
+++ b/crates/hir-expand/src/mod_path.rs
@@ -401,8 +401,8 @@ pub fn resolve_crate_root(db: &dyn ExpandDatabase, mut ctxt: SyntaxContext) -> O
result_mark = Some(mark);
iter.next();
}
- // Then find the last semi-transparent mark from the end if it exists.
- while let Some((mark, Transparency::SemiTransparent)) = iter.next() {
+ // Then find the last semi-opaque mark from the end if it exists.
+ while let Some((mark, Transparency::SemiOpaque)) = iter.next() {
result_mark = Some(mark);
}